@@ -1,7 +1,7 @@
 package CPAN::Info::FromURL;
 
 our $DATE = '2016-03-07'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,6 +12,7 @@ our @EXPORT_OK = qw(extract_cpan_info_from_url);
 
 our %SPEC;
 
+our $re_proto_http = qr!(?:https?://)!i;
 our $re_author   = qr/(?:\w+)/;
 our $re_dist     = qr/(?:\w+(?:-\w+)*)/;
 our $re_mod      = qr/(?:\w+(?:::\w+)*)/;
@@ -53,7 +54,7 @@ _
         },
         {
             name => "mcpan/module/MOD",
-            args => {url=>'https://metacpan.org/module/Foo?'},
+            args => {url=>'metacpan.org/module/Foo?'},
             result => {site=>'mcpan', module=>'Foo'},
         },
         {
@@ -169,7 +170,7 @@ sub extract_cpan_info_from_url {
     my $res;
 
     # metacpan
-    if ($url =~ s!\Ahttps?://(api\.)?metacpan\.org/?!!i) {
+    if ($url =~ s!\A$re_proto_http?(api\.)?metacpan\.org/?!!i) {
 
         $res->{site} = 'mcpan';
         # note: /module is the old URL. /pod might misreport a script as a
@@ -216,7 +217,7 @@ sub extract_cpan_info_from_url {
             $res->{author} = $1;
         }
 
-    } elsif ($url =~ s!\Ahttps?://search\.cpan\.org/?!!i) {
+    } elsif ($url =~ s!\A$re_proto_http?search\.cpan\.org/?!!i) {
 
         $res->{site} = 'sco';
         if ($url =~ m!\Adist/
@@ -259,7 +260,7 @@ sub extract_cpan_info_from_url {
             }
         }
 
-    } elsif ($url =~ s!\Ahttps?://cpanratings\.perl\.org/?!!i) {
+    } elsif ($url =~ s!\A$re_proto_http?cpanratings\.perl\.org/?!!i) {
 
         $res->{site} = 'cpanratings';
         if ($url =~ m!\Adist/
@@ -268,7 +269,7 @@ sub extract_cpan_info_from_url {
             $res->{dist} = $1;
         }
 
-    } elsif ($url =~ s!\Ahttps?://rt\.cpan\.org/?!!i) {
+    } elsif ($url =~ s!\A$re_proto_http?rt\.cpan\.org/?!!i) {
 
         $res->{site} = 'rt';
         if ($url =~ m!\A(?:Public/)?Dist/Display\.html!) {
@@ -310,7 +311,7 @@ CPAN::Info::FromURL - Extract/guess information from a URL
 
 =head1 VERSION
 
-This document describes version 0.05 of CPAN::Info::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-03-07.
+This document describes version 0.06 of CPAN::Info::FromURL (from Perl distribution CPAN-Info-FromURL), released on 2016-03-07.
 
 =head1 FUNCTIONS
 
@@ -329,7 +330,7 @@ Examples:
 
 =item * Example #2:
 
- extract_cpan_info_from_url("https://metacpan.org/module/Foo?"); # -> { module => "Foo", site => "mcpan" }
+ extract_cpan_info_from_url("metacpan.org/module/Foo?"); # -> { module => "Foo", site => "mcpan" }
 
 =item * Example #3:
 
